[Openmp-commits] [openmp] 4c6a098 - [OpenMP] NFC: Fix trivial typos in comments

Jim Lin via Openmp-commits openmp-commits at lists.llvm.org
Mon Jan 6 22:01:59 PST 2020


Author: Kazuaki Ishizaki
Date: 2020-01-07T14:05:03+08:00
New Revision: 4c6a098ad52fc2844f7733bc051cd7a729500f04

URL: https://github.com/llvm/llvm-project/commit/4c6a098ad52fc2844f7733bc051cd7a729500f04
DIFF: https://github.com/llvm/llvm-project/commit/4c6a098ad52fc2844f7733bc051cd7a729500f04.diff

LOG: [OpenMP] NFC: Fix trivial typos in comments

Reviewers: jdoerfert, Jim

Reviewed By: Jim

Subscribers: Jim, mgorny, guansong, jfb, openmp-commits

Tags: #openmp

Differential Revision: https://reviews.llvm.org/D72285

Added: 
    

Modified: 
    openmp/libomptarget/deviceRTLs/common/debug.h
    openmp/libomptarget/deviceRTLs/common/omptarget.h
    openmp/libomptarget/deviceRTLs/common/src/libcall.cu
    openmp/libomptarget/deviceRTLs/common/src/omptarget.cu
    openmp/libomptarget/deviceRTLs/common/src/parallel.cu
    openmp/libomptarget/deviceRTLs/common/src/task.cu
    openmp/libomptarget/deviceRTLs/nvptx/test/parallel/level.c
    openmp/libomptarget/plugins/cuda/src/rtl.cpp
    openmp/libomptarget/src/private.h
    openmp/runtime/cmake/LibompMicroTests.cmake
    openmp/runtime/cmake/config-ix.cmake
    openmp/runtime/src/extractExternal.cpp
    openmp/runtime/src/i18n/en_US.txt
    openmp/runtime/src/include/omp_lib.f.var
    openmp/runtime/src/kmp.h
    openmp/runtime/src/kmp_affinity.cpp
    openmp/runtime/src/kmp_atomic.cpp
    openmp/runtime/src/kmp_dispatch.cpp
    openmp/runtime/src/kmp_gsupport.cpp
    openmp/runtime/src/kmp_itt.inl
    openmp/runtime/src/kmp_lock.h
    openmp/runtime/src/kmp_runtime.cpp
    openmp/runtime/src/kmp_settings.cpp
    openmp/runtime/src/kmp_stats.cpp
    openmp/runtime/src/kmp_taskdeps.cpp
    openmp/runtime/src/kmp_tasking.cpp
    openmp/runtime/src/kmp_wrapper_malloc.h
    openmp/runtime/src/thirdparty/ittnotify/ittnotify.h
    openmp/runtime/src/thirdparty/ittnotify/ittnotify_static.cpp
    openmp/runtime/src/thirdparty/ittnotify/legacy/ittnotify.h
    openmp/runtime/test/ompt/synchronization/lock.c
    openmp/runtime/test/ompt/synchronization/nest_lock.c
    openmp/runtime/test/threadprivate/omp_threadprivate.c
    openmp/runtime/tools/check-depends.pl
    openmp/runtime/tools/generate-def.pl
    openmp/runtime/tools/lib/Uname.pm
    openmp/runtime/tools/lib/tools.pm
    openmp/runtime/tools/message-converter.pl
    openmp/tools/archer/tests/races/task-dependency.c

Removed: 
    


################################################################################
diff  --git a/openmp/libomptarget/deviceRTLs/common/debug.h b/openmp/libomptarget/deviceRTLs/common/debug.h
index 8bb4e3a6dd0c..b232490c43c2 100644
--- a/openmp/libomptarget/deviceRTLs/common/debug.h
+++ b/openmp/libomptarget/deviceRTLs/common/debug.h
@@ -123,7 +123,7 @@
 #endif
 
 ////////////////////////////////////////////////////////////////////////////////
-// implemtation for debug
+// implementation for debug
 ////////////////////////////////////////////////////////////////////////////////
 
 #if OMPTARGET_NVPTX_DEBUG || OMPTARGET_NVPTX_TEST || OMPTARGET_NVPTX_WARNING

diff  --git a/openmp/libomptarget/deviceRTLs/common/omptarget.h b/openmp/libomptarget/deviceRTLs/common/omptarget.h
index 8f577f7364d9..d17edb05e6aa 100644
--- a/openmp/libomptarget/deviceRTLs/common/omptarget.h
+++ b/openmp/libomptarget/deviceRTLs/common/omptarget.h
@@ -214,7 +214,7 @@ class omptarget_nvptx_TeamDescr {
     // If this is invoked by the master thread of the master warp then intialize
     // it with a smaller slot.
     if (IsMasterThread) {
-      // Do not initalize this slot again if it has already been initalized.
+      // Do not initialize this slot again if it has already been initalized.
       if (master_rootS[0].DataEnd == &master_rootS[0].Data[0] + DS_Slot_Size)
         return 0;
       // Initialize the pointer to the end of the slot given the size of the
@@ -226,7 +226,7 @@ class omptarget_nvptx_TeamDescr {
       master_rootS[0].PrevSlotStackPtr = 0;
       return (__kmpc_data_sharing_slot *)&master_rootS[0];
     }
-    // Do not initalize this slot again if it has already been initalized.
+    // Do not initialize this slot again if it has already been initalized.
     if (worker_rootS[wid].DataEnd ==
         &worker_rootS[wid].Data[0] + DS_Worker_Warp_Slot_Size)
       return 0;
@@ -301,7 +301,7 @@ class omptarget_nvptx_ThreadPrivateContext {
 private:
   // team context for this team
   omptarget_nvptx_TeamDescr teamContext;
-  // task ICV for implict threads in the only parallel region
+  // task ICV for implicit threads in the only parallel region
   omptarget_nvptx_TaskDescr levelOneTaskDescr[MAX_THREADS_PER_TEAM];
   // pointer where to find the current task ICV (top of the stack)
   omptarget_nvptx_TaskDescr *topTaskDescr[MAX_THREADS_PER_TEAM];

diff  --git a/openmp/libomptarget/deviceRTLs/common/src/libcall.cu b/openmp/libomptarget/deviceRTLs/common/src/libcall.cu
index 5f65f9e52730..11a888fda275 100644
--- a/openmp/libomptarget/deviceRTLs/common/src/libcall.cu
+++ b/openmp/libomptarget/deviceRTLs/common/src/libcall.cu
@@ -363,8 +363,8 @@ EXTERN int omp_test_lock(omp_lock_t *lock) {
   return rc;
 }
 
-// for xlf Fotran
-// Fotran, the return is LOGICAL type
+// for xlf Fortran
+// Fortran, the return is LOGICAL type
 
 #define FLOGICAL long
 EXTERN FLOGICAL __xlf_omp_is_initial_device_i8() {

diff  --git a/openmp/libomptarget/deviceRTLs/common/src/omptarget.cu b/openmp/libomptarget/deviceRTLs/common/src/omptarget.cu
index 9bf27bfcbf18..da35ab6fcc98 100644
--- a/openmp/libomptarget/deviceRTLs/common/src/omptarget.cu
+++ b/openmp/libomptarget/deviceRTLs/common/src/omptarget.cu
@@ -143,7 +143,7 @@ EXTERN void __kmpc_spmd_kernel_init(int ThreadLimit, int16_t RequiresOMPRuntime,
         (int)newTaskDescr->ThreadId(), (int)ThreadLimit);
 
   if (RequiresDataSharing && GetLaneId() == 0) {
-    // Warp master innitializes data sharing environment.
+    // Warp master initializes data sharing environment.
     unsigned WID = threadId / WARPSIZE;
     __kmpc_data_sharing_slot *RootS = currTeamDescr.RootS(
         WID, WID == WARPSIZE - 1);

diff  --git a/openmp/libomptarget/deviceRTLs/common/src/parallel.cu b/openmp/libomptarget/deviceRTLs/common/src/parallel.cu
index 2a02c69e7e84..ab031e99e51f 100644
--- a/openmp/libomptarget/deviceRTLs/common/src/parallel.cu
+++ b/openmp/libomptarget/deviceRTLs/common/src/parallel.cu
@@ -6,7 +6,7 @@
 //
 //===----------------------------------------------------------------------===//
 //
-// Parallel implemention in the GPU. Here is the pattern:
+// Parallel implementation in the GPU. Here is the pattern:
 //
 //    while (not finished) {
 //

diff  --git a/openmp/libomptarget/deviceRTLs/common/src/task.cu b/openmp/libomptarget/deviceRTLs/common/src/task.cu
index d04ec50afd37..5e5bc350d277 100644
--- a/openmp/libomptarget/deviceRTLs/common/src/task.cu
+++ b/openmp/libomptarget/deviceRTLs/common/src/task.cu
@@ -84,7 +84,7 @@ EXTERN int32_t __kmpc_omp_task_with_deps(kmp_Ident *loc, uint32_t global_tid,
         P64(newKmpTaskDescr));
   ASSERT0(LT_FUSSY, checkRuntimeInitialized(loc),
           "Runtime must be initialized.");
-  // 1. get explict task descr from kmp task descr
+  // 1. get explicit task descr from kmp task descr
   omptarget_nvptx_ExplicitTaskDescr *newExplicitTaskDescr =
       (omptarget_nvptx_ExplicitTaskDescr *)SUB_BYTES(
           newKmpTaskDescr, sizeof(omptarget_nvptx_TaskDescr));
@@ -123,7 +123,7 @@ EXTERN void __kmpc_omp_task_begin_if0(kmp_Ident *loc, uint32_t global_tid,
         (unsigned long long)newKmpTaskDescr);
   ASSERT0(LT_FUSSY, checkRuntimeInitialized(loc),
           "Runtime must be initialized.");
-  // 1. get explict task descr from kmp task descr
+  // 1. get explicit task descr from kmp task descr
   omptarget_nvptx_ExplicitTaskDescr *newExplicitTaskDescr =
       (omptarget_nvptx_ExplicitTaskDescr *)SUB_BYTES(
           newKmpTaskDescr, sizeof(omptarget_nvptx_TaskDescr));
@@ -149,7 +149,7 @@ EXTERN void __kmpc_omp_task_complete_if0(kmp_Ident *loc, uint32_t global_tid,
         (unsigned long long)newKmpTaskDescr);
   ASSERT0(LT_FUSSY, checkRuntimeInitialized(loc),
           "Runtime must be initialized.");
-  // 1. get explict task descr from kmp task descr
+  // 1. get explicit task descr from kmp task descr
   omptarget_nvptx_ExplicitTaskDescr *newExplicitTaskDescr =
       (omptarget_nvptx_ExplicitTaskDescr *)SUB_BYTES(
           newKmpTaskDescr, sizeof(omptarget_nvptx_TaskDescr));

diff  --git a/openmp/libomptarget/deviceRTLs/nvptx/test/parallel/level.c b/openmp/libomptarget/deviceRTLs/nvptx/test/parallel/level.c
index 33e232464567..2d882195de74 100644
--- a/openmp/libomptarget/deviceRTLs/nvptx/test/parallel/level.c
+++ b/openmp/libomptarget/deviceRTLs/nvptx/test/parallel/level.c
@@ -53,7 +53,7 @@ int main(int argc, char *argv[]) {
       check2[id] += omp_get_ancestor_thread_num(0) + 5 * omp_get_team_size(0);
       // Expected to return the current thread num.
       check2[id] += (omp_get_ancestor_thread_num(1) - id);
-      // Exepcted to return the current number of threads.
+      // Expected to return the current number of threads.
       check2[id] += 3 * omp_get_team_size(1);
       // Expected to return -1, see above.
       check2[id] += omp_get_ancestor_thread_num(2) + omp_get_team_size(2);
@@ -68,7 +68,7 @@ int main(int argc, char *argv[]) {
         int check4Inc = omp_get_ancestor_thread_num(0) + 5 * omp_get_team_size(0);
         // Expected to return the parent thread num.
         check4Inc += (omp_get_ancestor_thread_num(1) - id);
-        // Exepcted to return the number of threads in the active parallel region.
+        // Expected to return the number of threads in the active parallel region.
         check4Inc += 3 * omp_get_team_size(1);
         // Exptected to return 0 and 1.
         check4Inc += omp_get_ancestor_thread_num(2) + 3 * omp_get_team_size(2);

diff  --git a/openmp/libomptarget/src/private.h b/openmp/libomptarget/src/private.h
index 20470a69baa4..7aaa295d9686 100644
--- a/openmp/libomptarget/src/private.h
+++ b/openmp/libomptarget/src/private.h
@@ -60,7 +60,7 @@ struct MapperComponentsTy {
 };
 
 ////////////////////////////////////////////////////////////////////////////////
-// implemtation for fatal messages
+// implementation for fatal messages
 ////////////////////////////////////////////////////////////////////////////////
 
 #define FATAL_MESSAGE0(_num, _str)                                    \

diff  --git a/openmp/runtime/cmake/LibompMicroTests.cmake b/openmp/runtime/cmake/LibompMicroTests.cmake
index a7bf8240bdff..d6e4db24d612 100644
--- a/openmp/runtime/cmake/LibompMicroTests.cmake
+++ b/openmp/runtime/cmake/LibompMicroTests.cmake
@@ -22,7 +22,7 @@
 #  - Available for Unix, Intel(R) MIC Architecture dynamic library builds. Not available otherwise.
 # (3) test-execstack
 #  - Tests if stack is executable
-#  - Fails if stack is executable. Should only be readable and writable. Not exectuable.
+#  - Fails if stack is executable. Should only be readable and writable. Not executable.
 #  - Program dependencies: perl, readelf
 #  - Available for Unix dynamic library builds. Not available otherwise.
 # (4) test-instr (Intel(R) MIC Architecutre only)

diff  --git a/openmp/runtime/cmake/config-ix.cmake b/openmp/runtime/cmake/config-ix.cmake
index f00746d9eadb..3419dd8cd788 100644
--- a/openmp/runtime/cmake/config-ix.cmake
+++ b/openmp/runtime/cmake/config-ix.cmake
@@ -87,7 +87,7 @@ if(WIN32)
   endforeach()
 else()
   # It is 
diff icult to create a dummy assembly file that compiles into an
-  # exectuable for every architecture and then check the C compiler to
+  # executable for every architecture and then check the C compiler to
   # see if -x assembler-with-cpp exists and works, so we assume it does for non-Windows.
   set(LIBOMP_HAVE_X_ASSEMBLER_WITH_CPP_FLAG TRUE)
 endif()

diff  --git a/openmp/runtime/src/extractExternal.cpp b/openmp/runtime/src/extractExternal.cpp
index b3e55b555d28..f512ecb2b16d 100644
--- a/openmp/runtime/src/extractExternal.cpp
+++ b/openmp/runtime/src/extractExternal.cpp
@@ -57,7 +57,7 @@ class _rstream : public istrstream {
   ~_rstream() { delete[] buf; }
 };
 
-// A stream encapuslating the content of a file or the content of a string,
+// A stream encapsulating the content of a file or the content of a string,
 // overriding the >> operator to read various integer types in binary form,
 // as well as a symbol table entry.
 class rstream : public _rstream {

diff  --git a/openmp/runtime/src/i18n/en_US.txt b/openmp/runtime/src/i18n/en_US.txt
index 650d5fec93a2..3a3035b26673 100644
--- a/openmp/runtime/src/i18n/en_US.txt
+++ b/openmp/runtime/src/i18n/en_US.txt
@@ -372,7 +372,7 @@ AffParseFilename             "%1$s: parsing %2$s."
 MsgExiting                   "%1$s - exiting."
 IncompatibleLibrary          "Incompatible %1$s library with version %2$s found."
 IttFunctionError             "ittnotify: Function %1$s failed:"
-IttUnknownError              "ittnofify: Error #%1$d."
+IttUnknownError              "ittnotify: Error #%1$d."
 EnvMiddleWarn                "%1$s must be set prior to first parallel region or certain API calls; ignored."
 CnsLockNotDestroyed          "Lock initialized at %1$s(%2$d) was not destroyed"
                                  # %1, %2, %3, %4 -- file, line, func, col

diff  --git a/openmp/runtime/src/include/omp_lib.f.var b/openmp/runtime/src/include/omp_lib.f.var
index 19f14d75f21c..d631438f55ad 100644
--- a/openmp/runtime/src/include/omp_lib.f.var
+++ b/openmp/runtime/src/include/omp_lib.f.var
@@ -953,7 +953,7 @@
 !dec$ if defined(__APPLE__)
 
 !***
-!*** The Mac entry points are in lowercase, with an both an underscore
+!*** The Mac entry points are in lowercase, with both an underscore
 !*** appended and an underscore prepended.
 !***
 

diff  --git a/openmp/runtime/src/kmp.h b/openmp/runtime/src/kmp.h
index 0b8397e2c238..086ab3bb011e 100644
--- a/openmp/runtime/src/kmp.h
+++ b/openmp/runtime/src/kmp.h
@@ -203,7 +203,7 @@ enum {
   KMP_IDENT_WORK_LOOP = 0x200,
   /*! To mark a sections directive in OMPT callbacks */
   KMP_IDENT_WORK_SECTIONS = 0x400,
-  /*! To mark a distirbute construct in OMPT callbacks */
+  /*! To mark a distribute construct in OMPT callbacks */
   KMP_IDENT_WORK_DISTRIBUTE = 0x800,
   /*! Atomic hint; bottom four bits as omp_sync_hint_t. Top four reserved and
       not currently used. If one day we need more bits, then we can use
@@ -868,7 +868,7 @@ extern int __kmp_hws_abs_flag; // absolute or per-item number requested
 /* OpenMP 5.0 Memory Management support */
 
 #ifndef __OMP_H
-// Duplicate type definitios from omp.h
+// Duplicate type definitions from omp.h
 typedef uintptr_t omp_uintptr_t;
 
 typedef enum {
@@ -929,7 +929,7 @@ extern omp_allocator_handle_t const omp_thread_mem_alloc;
 extern omp_allocator_handle_t const kmp_max_mem_alloc;
 extern omp_allocator_handle_t __kmp_def_allocator;
 
-// end of duplicate type definitios from omp.h
+// end of duplicate type definitions from omp.h
 #endif
 
 extern int __kmp_memkind_available;
@@ -1389,7 +1389,7 @@ The type for a microtask which gets passed to @ref __kmpc_fork_call().
 The arguments to the outlined function are
 @param global_tid the global thread identity of the thread executing the
 function.
- at param bound_tid  the local identitiy of the thread executing the function
+ at param bound_tid  the local identity of the thread executing the function
 @param ... pointers to shared variables accessed by the function.
 */
 typedef void (*kmpc_micro)(kmp_int32 *global_tid, kmp_int32 *bound_tid, ...);
@@ -2654,7 +2654,7 @@ typedef struct KMP_ALIGN_CACHE kmp_base_team {
   int t_level; // nested parallel level
 
   KMP_ALIGN_CACHE int t_max_argc;
-  int t_max_nproc; // max threads this team can handle (dynamicly expandable)
+  int t_max_nproc; // max threads this team can handle (dynamically expandable)
   int t_serialized; // levels deep of serialized teams
   dispatch_shared_info_t *t_disp_buffer; // buffers for dispatch system
   int t_id; // team's id, assigned by debugger.

diff  --git a/openmp/runtime/src/kmp_affinity.cpp b/openmp/runtime/src/kmp_affinity.cpp
index 012d2a2c4702..650e9ff35e1b 100644
--- a/openmp/runtime/src/kmp_affinity.cpp
+++ b/openmp/runtime/src/kmp_affinity.cpp
@@ -1124,7 +1124,7 @@ static int __kmp_affinity_create_apicid_map(AddrUnsPair **address2os,
     // - Older OSes are usually found on machines with older chips, which do not
     //   support HT.
     // - The performance penalty for mistakenly identifying a machine as HT when
-    //   it isn't (which results in blocktime being incorrecly set to 0) is
+    //   it isn't (which results in blocktime being incorrectly set to 0) is
     //   greater than the penalty when for mistakenly identifying a machine as
     //   being 1 thread/core when it is really HT enabled (which results in
     //   blocktime being incorrectly set to a positive value).
@@ -4194,7 +4194,7 @@ static void __kmp_aux_affinity_initialize(void) {
   if (__kmp_affinity_top_method == affinity_top_method_all) {
     // In the default code path, errors are not fatal - we just try using
     // another method. We only emit a warning message if affinity is on, or the
-    // verbose flag is set, an the nowarnings flag was not set.
+    // verbose flag is set, and the nowarnings flag was not set.
     const char *file_name = NULL;
     int line = 0;
 #if KMP_USE_HWLOC

diff  --git a/openmp/runtime/src/kmp_atomic.cpp b/openmp/runtime/src/kmp_atomic.cpp
index fe80ba8b2836..148b2da3f524 100644
--- a/openmp/runtime/src/kmp_atomic.cpp
+++ b/openmp/runtime/src/kmp_atomic.cpp
@@ -141,7 +141,7 @@ Full list of functions
 ======================
 This leads to the generation of 376 atomic functions, as follows.
 
-Functons for integers
+Functions for integers
 ---------------------
 There are versions here for integers of size 1,2,4 and 8 bytes both signed and
 unsigned (where that matters).

diff  --git a/openmp/runtime/src/kmp_dispatch.cpp b/openmp/runtime/src/kmp_dispatch.cpp
index aee1a649741c..a91ffa2ba299 100644
--- a/openmp/runtime/src/kmp_dispatch.cpp
+++ b/openmp/runtime/src/kmp_dispatch.cpp
@@ -1533,7 +1533,7 @@ int __kmp_dispatch_next_algorithm(int gtid,
       if ((T)remaining <
           pr->u.p.parm2) { // compare with K*nproc*(chunk+1), K=2 by default
         // use dynamic-style shcedule
-        // atomically inrement iterations, get old value
+        // atomically increment iterations, get old value
         init = test_then_add<ST>(RCAST(volatile ST *, &sh->u.s.iteration),
                                  (ST)chunkspec);
         remaining = trip - init;
@@ -1602,7 +1602,7 @@ int __kmp_dispatch_next_algorithm(int gtid,
       // compare with K*nproc*(chunk+1), K=2 by default
       if ((T)remaining < pr->u.p.parm2) {
         // use dynamic-style shcedule
-        // atomically inrement iterations, get old value
+        // atomically increment iterations, get old value
         init = test_then_add<ST>(RCAST(volatile ST *, &sh->u.s.iteration),
                                  (ST)chunk);
         remaining = trip - init;
@@ -1893,7 +1893,7 @@ static int __kmp_dispatch_next(ident_t *loc, int gtid, kmp_int32 *p_last,
   typedef typename traits_t<T>::signed_t ST;
   // This is potentially slightly misleading, schedule(runtime) will appear here
   // even if the actual runtme schedule is static. (Which points out a
-  // disadavantage of schedule(runtime): even when static scheduling is used it
+  // disadvantage of schedule(runtime): even when static scheduling is used it
   // costs more than a compile time choice to use static scheduling would.)
   KMP_TIME_PARTITIONED_BLOCK(OMP_loop_dynamic_scheduling);
 

diff  --git a/openmp/runtime/src/kmp_gsupport.cpp b/openmp/runtime/src/kmp_gsupport.cpp
index da8b3211733c..e0739a737d9c 100644
--- a/openmp/runtime/src/kmp_gsupport.cpp
+++ b/openmp/runtime/src/kmp_gsupport.cpp
@@ -495,7 +495,7 @@ void KMP_EXPAND_NAME(KMP_API_NAME_GOMP_PARALLEL_END)(void) {
 // argument to __kmp_GOMP_fork_call).
 //
 // Conversely, KMP_DISPATCH_NEXT returns and inclusive upper bound in *p_ub,
-// but the Gnu codegen expects an excluside upper bound, so the adjustment
+// but the Gnu codegen expects an exclusive upper bound, so the adjustment
 // "*p_ub += stride" compensates for the discrepancy.
 //
 // Correction: the gnu codegen always adjusts the upper bound by +-1, not the
@@ -1743,7 +1743,7 @@ void __GOMP_taskloop(void (*func)(void *), void *data,
 
 // 4 byte version of GOMP_doacross_post
 // This verison needs to create a temporary array which converts 4 byte
-// integers into 8 byte integeres
+// integers into 8 byte integers
 template <typename T, bool need_conversion = (sizeof(long) == 4)>
 void __kmp_GOMP_doacross_post(T *count);
 

diff  --git a/openmp/runtime/src/kmp_itt.inl b/openmp/runtime/src/kmp_itt.inl
index fe449ac604b4..04f00285ba35 100644
--- a/openmp/runtime/src/kmp_itt.inl
+++ b/openmp/runtime/src/kmp_itt.inl
@@ -474,7 +474,7 @@ LINKAGE void __kmp_itt_region_joined(int gtid) {
    ITT need an address (void *) to be specified as a sync object. OpenMP RTL
    does not have barrier object or barrier data structure. Barrier is just a
    counter in team and thread structures. We could use an address of team
-   structure as an barrier sync object, but ITT wants 
diff erent objects for
+   structure as a barrier sync object, but ITT wants 
diff erent objects for
    
diff erent barriers (even whithin the same team). So let us use team address
    as barrier sync object for the first barrier, then increase it by one for the
    next barrier, and so on (but wrap it not to use addresses outside of team
@@ -505,7 +505,7 @@ void *__kmp_itt_barrier_object(int gtid, int bt, int set_name,
     // This condition is a must (we would have zero divide otherwise).
     KMP_BUILD_ASSERT(sizeof(kmp_team_t) >= 2 * bs_last_barrier);
     // More strong condition: make sure we have room at least for for two
-    // 
diff ertent ids (for each barrier type).
+    // 
diff erent ids (for each barrier type).
     object = reinterpret_cast<void *>(
         kmp_uintptr_t(team) +
         counter % (sizeof(kmp_team_t) / bs_last_barrier) * bs_last_barrier +

diff  --git a/openmp/runtime/src/kmp_lock.h b/openmp/runtime/src/kmp_lock.h
index 9ad86a51657d..75a15f084c69 100644
--- a/openmp/runtime/src/kmp_lock.h
+++ b/openmp/runtime/src/kmp_lock.h
@@ -462,7 +462,7 @@ struct kmp_base_drdpa_lock {
   // written by the acquiring thread) than it does in the simple ticket locks
   // (where it is written by the releasing thread).
   //
-  // Since now_serving is only read an written in the critical section,
+  // Since now_serving is only read and written in the critical section,
   // it is non-volatile, but it needs to exist on a separate cache line,
   // as it is invalidated at every lock acquire.
   //

diff  --git a/openmp/runtime/src/kmp_runtime.cpp b/openmp/runtime/src/kmp_runtime.cpp
index 4f4559589e9b..acd157db8e52 100644
--- a/openmp/runtime/src/kmp_runtime.cpp
+++ b/openmp/runtime/src/kmp_runtime.cpp
@@ -3927,8 +3927,8 @@ static int __kmp_reset_root(int gtid, kmp_root_t *root) {
   }
   __kmp_reap_thread(root->r.r_uber_thread, 1);
 
-  // We canot put root thread to __kmp_thread_pool, so we have to reap it istead
-  // of freeing.
+  // We canot put root thread to __kmp_thread_pool, so we have to reap it
+  // instead of freeing.
   root->r.r_uber_thread = NULL;
   /* mark root as no longer in use */
   root->r.r_begin = FALSE;

diff  --git a/openmp/runtime/src/kmp_settings.cpp b/openmp/runtime/src/kmp_settings.cpp
index 692ca26d0e42..c7dec4d218c6 100644
--- a/openmp/runtime/src/kmp_settings.cpp
+++ b/openmp/runtime/src/kmp_settings.cpp
@@ -1034,7 +1034,7 @@ static void __kmp_parse_nested_num_threads(const char *var, const char *env,
     }
     // The next character is ','
     if (*next == ',') {
-      // ',' is the fisrt character
+      // ',' is the first character
       if (total == 0 || prev_comma) {
         total++;
       }
@@ -4205,7 +4205,7 @@ static void __kmp_stg_parse_spin_backoff_params(const char *name,
     }
     // The next character is ','
     if (*next == ',') {
-      // ',' is the fisrt character
+      // ',' is the first character
       if (total == 0 || prev_comma) {
         total++;
       }
@@ -4304,7 +4304,7 @@ static void __kmp_stg_parse_adaptive_lock_props(const char *name,
     }
     // The next character is ','
     if (*next == ',') {
-      // ',' is the fisrt character
+      // ',' is the first character
       if (total == 0 || prev_comma) {
         total++;
       }

diff  --git a/openmp/runtime/src/kmp_stats.cpp b/openmp/runtime/src/kmp_stats.cpp
index 71f2dd93be79..dabd0c35b85c 100644
--- a/openmp/runtime/src/kmp_stats.cpp
+++ b/openmp/runtime/src/kmp_stats.cpp
@@ -679,7 +679,7 @@ void kmp_stats_output_module::printEvents(FILE *eventsOut,
 
 void kmp_stats_output_module::windupExplicitTimers() {
   // Wind up any explicit timers. We assume that it's fair at this point to just
-  // walk all the explcit timers in all threads and say "it's over".
+  // walk all the explicit timers in all threads and say "it's over".
   // If the timer wasn't running, this won't record anything anyway.
   kmp_stats_list::iterator it;
   for (it = __kmp_stats_list->begin(); it != __kmp_stats_list->end(); it++) {

diff  --git a/openmp/runtime/src/kmp_taskdeps.cpp b/openmp/runtime/src/kmp_taskdeps.cpp
index 8d60bbbc816b..e1618f5cd9df 100644
--- a/openmp/runtime/src/kmp_taskdeps.cpp
+++ b/openmp/runtime/src/kmp_taskdeps.cpp
@@ -417,7 +417,7 @@ static bool __kmp_check_deps(kmp_int32 gtid, kmp_depnode_t *node,
   kmp_taskdata_t *taskdata = KMP_TASK_TO_TASKDATA(task);
 #endif
   KA_TRACE(20, ("__kmp_check_deps: T#%d checking dependencies for task %p : %d "
-                "possibly aliased dependencies, %d non-aliased depedencies : "
+                "possibly aliased dependencies, %d non-aliased dependencies : "
                 "dep_barrier=%d .\n",
                 gtid, taskdata, ndeps, ndeps_noalias, dep_barrier));
 

diff  --git a/openmp/runtime/src/kmp_tasking.cpp b/openmp/runtime/src/kmp_tasking.cpp
index 7911f1cad0f8..15ffc1454fe9 100644
--- a/openmp/runtime/src/kmp_tasking.cpp
+++ b/openmp/runtime/src/kmp_tasking.cpp
@@ -3169,7 +3169,7 @@ static void __kmp_free_task_deque(kmp_thread_data_t *thread_data) {
 // __kmp_realloc_task_threads_data:
 // Allocates a threads_data array for a task team, either by allocating an
 // initial array or enlarging an existing array.  Only the first thread to get
-// the lock allocs or enlarges the array and re-initializes the array eleemnts.
+// the lock allocs or enlarges the array and re-initializes the array elements.
 // That thread returns "TRUE", the rest return "FALSE".
 // Assumes that the new array size is given by task_team -> tt.tt_nproc.
 // The current size is given by task_team -> tt.tt_max_threads.
@@ -4144,7 +4144,8 @@ void __kmp_taskloop_linear(ident_t *loc, int gtid, kmp_task_t *task,
     } else {
       next_task_bounds.set_ub(upper);
     }
-    if (ptask_dup != NULL) // set lastprivate flag, construct fistprivates, etc.
+    if (ptask_dup != NULL) // set lastprivate flag, construct firstprivates,
+                           // etc.
       ptask_dup(next_task, task, lastpriv);
     KA_TRACE(40,
              ("__kmp_taskloop_linear: T#%d; task #%llu: task %p: lower %lld, "
@@ -4313,7 +4314,7 @@ void __kmp_taskloop_recur(ident_t *loc, int gtid, kmp_task_t *task,
   next_task = __kmp_task_dup_alloc(thread, task); // duplicate the task
   // adjust lower bound (upper bound is not changed) for the 2nd half
   *(kmp_uint64 *)((char *)next_task + lower_offset) = lb1;
-  if (ptask_dup != NULL) // construct fistprivates, etc.
+  if (ptask_dup != NULL) // construct firstprivates, etc.
     ptask_dup(next_task, task, 0);
   *ub = ub0; // adjust upper bound for the 1st half
 

diff  --git a/openmp/runtime/src/kmp_wrapper_malloc.h b/openmp/runtime/src/kmp_wrapper_malloc.h
index a50387c7f7cc..1544c5df3d64 100644
--- a/openmp/runtime/src/kmp_wrapper_malloc.h
+++ b/openmp/runtime/src/kmp_wrapper_malloc.h
@@ -24,7 +24,7 @@
    On Linux* OS, alloca() function is declared in <alloca.h> header, while on
    Windows* OS there is no <alloca.h> header, function _alloca() (note
    underscore!) is declared in <malloc.h>. This header eliminates these
-   
diff erences, so client code incluiding "kmp_wrapper_malloc.h" can rely on
+   
diff erences, so client code including "kmp_wrapper_malloc.h" can rely on
    following routines:
 
         malloc

diff  --git a/openmp/runtime/src/thirdparty/ittnotify/ittnotify.h b/openmp/runtime/src/thirdparty/ittnotify/ittnotify.h
index ed46cd7761c3..d730c48ec705 100644
--- a/openmp/runtime/src/thirdparty/ittnotify/ittnotify.h
+++ b/openmp/runtime/src/thirdparty/ittnotify/ittnotify.h
@@ -1448,7 +1448,7 @@ ITT_STUBV(ITTAPI, void, heap_allocate_end, (__itt_heap_function h, void** addr,
 /** @endcond */
 
 /**
- * @brief Record an free begin occurrence.
+ * @brief Record a free begin occurrence.
  */
 void ITTAPI __itt_heap_free_begin(__itt_heap_function h, void* addr);
 
@@ -1468,7 +1468,7 @@ ITT_STUBV(ITTAPI, void, heap_free_begin, (__itt_heap_function h, void* addr))
 /** @endcond */
 
 /**
- * @brief Record an free end occurrence.
+ * @brief Record a free end occurrence.
  */
 void ITTAPI __itt_heap_free_end(__itt_heap_function h, void* addr);
 
@@ -1488,7 +1488,7 @@ ITT_STUBV(ITTAPI, void, heap_free_end, (__itt_heap_function h, void* addr))
 /** @endcond */
 
 /**
- * @brief Record an reallocation begin occurrence.
+ * @brief Record a reallocation begin occurrence.
  */
 void ITTAPI __itt_heap_reallocate_begin(__itt_heap_function h, void* addr, size_t new_size, int initialized);
 
@@ -1508,7 +1508,7 @@ ITT_STUBV(ITTAPI, void, heap_reallocate_begin, (__itt_heap_function h, void* add
 /** @endcond */
 
 /**
- * @brief Record an reallocation end occurrence.
+ * @brief Record a reallocation end occurrence.
  */
 void ITTAPI __itt_heap_reallocate_end(__itt_heap_function h, void* addr, void** new_addr, size_t new_size, int initialized);
 
@@ -2644,7 +2644,7 @@ ITT_STUB(ITTAPI, __itt_clock_domain*, clock_domain_create, (__itt_get_clock_info
 
 /**
  * @ingroup clockdomains
- * @brief Recalculate clock domains frequences and clock base timestamps.
+ * @brief Recalculate clock domains frequencies and clock base timestamps.
  */
 void ITTAPI __itt_clock_domain_reset(void);
 
@@ -3957,7 +3957,7 @@ ITT_STUB(ITTAPI, __itt_caller, stack_caller_create, (void))
 /** @endcond */
 
 /**
- * @brief Destroy the inforamtion about stitch point identified by the pointer previously returned by __itt_stack_caller_create()
+ * @brief Destroy the information about stitch point identified by the pointer previously returned by __itt_stack_caller_create()
  */
 void ITTAPI __itt_stack_caller_destroy(__itt_caller id);
 

diff  --git a/openmp/runtime/src/thirdparty/ittnotify/ittnotify_static.cpp b/openmp/runtime/src/thirdparty/ittnotify/ittnotify_static.cpp
index c48b3f420bb7..8f9e2a655ae4 100644
--- a/openmp/runtime/src/thirdparty/ittnotify/ittnotify_static.cpp
+++ b/openmp/runtime/src/thirdparty/ittnotify/ittnotify_static.cpp
@@ -786,7 +786,7 @@ static const char* __itt_get_env_var(const char* name)
         }
         else
         {
-            /* If environment variable is empty, GetEnvirornmentVariables()
+            /* If environment variable is empty, GetEnvironmentVariables()
              * returns zero (number of characters (not including terminating null),
              * and GetLastError() returns ERROR_SUCCESS. */
             DWORD err = GetLastError();

diff  --git a/openmp/runtime/src/thirdparty/ittnotify/legacy/ittnotify.h b/openmp/runtime/src/thirdparty/ittnotify/legacy/ittnotify.h
index eae33e0b1942..a4061e168d1d 100644
--- a/openmp/runtime/src/thirdparty/ittnotify/legacy/ittnotify.h
+++ b/openmp/runtime/src/thirdparty/ittnotify/legacy/ittnotify.h
@@ -957,9 +957,9 @@ ITT_STUB(ITTAPI, __itt_frame, frame_create,  (const char *domain))
 #endif /* INTEL_NO_MACRO_BODY */
 /** @endcond */
 
-/** @brief Record an frame begin occurrence. */
+/** @brief Record a frame begin occurrence. */
 void ITTAPI __itt_frame_begin(__itt_frame frame);
-/** @brief Record an frame end occurrence. */
+/** @brief Record a frame end occurrence. */
 void ITTAPI __itt_frame_end  (__itt_frame frame);
 
 /** @cond exclude_from_documentation */

diff  --git a/openmp/runtime/test/ompt/synchronization/lock.c b/openmp/runtime/test/ompt/synchronization/lock.c
index 2a934ee855ab..6a4f88a11cc2 100644
--- a/openmp/runtime/test/ompt/synchronization/lock.c
+++ b/openmp/runtime/test/ompt/synchronization/lock.c
@@ -5,7 +5,7 @@
 
 int main()
 {
-  //need to use an OpenMP construct so that OMPT will be initalized
+  //need to use an OpenMP construct so that OMPT will be initialized
   #pragma omp parallel num_threads(1)
     print_ids(0);
 

diff  --git a/openmp/runtime/test/ompt/synchronization/nest_lock.c b/openmp/runtime/test/ompt/synchronization/nest_lock.c
index 159048e2e74d..813c170c0d6f 100644
--- a/openmp/runtime/test/ompt/synchronization/nest_lock.c
+++ b/openmp/runtime/test/ompt/synchronization/nest_lock.c
@@ -5,7 +5,7 @@
 
 int main()
 {
-  //need to use an OpenMP construct so that OMPT will be initalized
+  //need to use an OpenMP construct so that OMPT will be initialized
   #pragma omp parallel num_threads(1)
     print_ids(0);
 

diff  --git a/openmp/runtime/test/threadprivate/omp_threadprivate.c b/openmp/runtime/test/threadprivate/omp_threadprivate.c
index a3dd80d9d5f7..48ac65877c41 100644
--- a/openmp/runtime/test/threadprivate/omp_threadprivate.c
+++ b/openmp/runtime/test/threadprivate/omp_threadprivate.c
@@ -62,7 +62,7 @@ int test_omp_threadprivate()
     my_random = rand(); /* random number generator is
                  called inside serial region*/
 
-    /* the first parallel region is used to initialiye myvalue
+    /* the first parallel region is used to initialize myvalue
        and the array with my_random+rank */
     #pragma omp parallel
     {

diff  --git a/openmp/runtime/tools/check-depends.pl b/openmp/runtime/tools/check-depends.pl
index 6f8c8af5a222..909df1cd9847 100755
--- a/openmp/runtime/tools/check-depends.pl
+++ b/openmp/runtime/tools/check-depends.pl
@@ -406,11 +406,11 @@ =head1 DESCRIPTION
 
 C<check-depends.pl> finds direct dependencies for a specified library. List of actual dependencies
 is sorted alphabetically and printed. If list of expected dependencies is specified, the scripts
-checks the library has only allowed dependencies. In case of not expected depndencies the script
+checks the library has only allowed dependencies. In case of not expected dependencies. the script
 issues error message and exits with non-zero code.
 
-Linux* OS and OS X*: The script finds dependencies only for dymamic libraries. Windows* OS: The script
-finds dependencies for either static or dymamic libraries.
+Linux* OS and OS X*: The script finds dependencies only for dynamic libraries. Windows* OS: The script
+finds dependencies for either static or dynamic libraries.
 
 The script uses external tools. On Linux* OS, it runs F<readelf>, on OS X* -- F<otool> (or F<otool64>),
 on Windows* OS -- F<link>.

diff  --git a/openmp/runtime/tools/generate-def.pl b/openmp/runtime/tools/generate-def.pl
index 754243c27f3f..a44306f7db23 100755
--- a/openmp/runtime/tools/generate-def.pl
+++ b/openmp/runtime/tools/generate-def.pl
@@ -94,7 +94,7 @@ ($\%)
 
     if ( @dirs ) {
         my $dir = pop( @dirs );
-        $error->( "Unterminated %if direcive.", $dir->{ n }, $dir->{ line } );
+        $error->( "Unterminated %if directive.", $dir->{ n }, $dir->{ line } );
     }; # while
 
     return %entries;

diff  --git a/openmp/runtime/tools/lib/Uname.pm b/openmp/runtime/tools/lib/Uname.pm
index 6b76a22997ee..99fe1cdbf00c 100644
--- a/openmp/runtime/tools/lib/Uname.pm
+++ b/openmp/runtime/tools/lib/Uname.pm
@@ -93,7 +93,7 @@ if ( $^O =~ m/cygwin/i ) {
     # is really requested.
     $values{ fqdn } =
         sub {
-            my $fqdn = Net::Domain::hostfqdn(); # "fqdn" stands for "fully qualified doamain name".
+            my $fqdn = Net::Domain::hostfqdn(); # "fqdn" stands for "fully qualified domain name".
             # On some systems POSIX::uname() and Net::Domain::hostfqdn() reports 
diff erent names.
             # Let us issue a warning if they significantly 
diff erent. Names are insignificantly
             # 
diff erent if POSIX::uname() matches the beginning of Net::Domain::hostfqdn().

diff  --git a/openmp/runtime/tools/lib/tools.pm b/openmp/runtime/tools/lib/tools.pm
index 9415037cba7d..f5aba2b32d50 100644
--- a/openmp/runtime/tools/lib/tools.pm
+++ b/openmp/runtime/tools/lib/tools.pm
@@ -875,7 +875,7 @@ Make a directory.
 This function makes a directory. If necessary, more than one level can be created.
 If directory exists, warning issues (the script behavior depends on value of
 C<-warning_level> option). If directory creation fails or C<$dir> exists but it is not a
-directory, error isssues.
+directory, error issues.
 
 Options:
 
@@ -1834,7 +1834,7 @@ Examples:
     execute( [ qw( cvs -n -q update . ) ], -stdout => \@output, -stderr => undef );
         # Execute specified command,  output is saved in @output
         # variable, stderr stream is redirected to null device
-        # (/dev/null in Linux* OS an nul in Windows* OS).
+        # (/dev/null in Linux* OS and nul in Windows* OS).
 
 =cut
 

diff  --git a/openmp/runtime/tools/message-converter.pl b/openmp/runtime/tools/message-converter.pl
index d72acf001901..b3efb706e59b 100755
--- a/openmp/runtime/tools/message-converter.pl
+++ b/openmp/runtime/tools/message-converter.pl
@@ -563,7 +563,7 @@ =head1 OPTIONS
 
 =item B<--os=>I<str>
 
-Specify OS name the message formats to be converted for. If not specified expolicitly, value of
+Specify OS name the message formats to be converted for. If not specified explicitly, value of
 LIBOMP_OS environment variable is used. If LIBOMP_OS is not defined, host OS is detected.
 
 Depending on OS, B<message-converter.pl> converts message formats to GNU style or MS style.
@@ -659,7 +659,7 @@ =head2 Output Files
         kmp_i18n_str_NotANumber,
         ...
 
-        // Set #3, fotrmats.
+        // Set #3, formats.
         ...
 
         kmp_i18n_xxx_lastest
@@ -709,7 +709,7 @@ =head2 Output Files
     2 "Japan"
     3 "1041"
     4 "2"
-    5 "Based on Enlish message catalog revision 20090806"
+    5 "Based on English message catalog revision 20090806"
     ...
 
 Example of Windows* OS message file:

diff  --git a/openmp/tools/archer/tests/races/task-dependency.c b/openmp/tools/archer/tests/races/task-dependency.c
index beb073de3d3d..ce418b8b5a6d 100644
--- a/openmp/tools/archer/tests/races/task-dependency.c
+++ b/openmp/tools/archer/tests/races/task-dependency.c
@@ -1,5 +1,5 @@
 /*
- * task-deoendency.c -- Archer testcase
+ * task-dependency.c -- Archer testcase
  */
 
 //===----------------------------------------------------------------------===//


        


More information about the Openmp-commits mailing list
diff  --git a/openmp/libomptarget/plugins/cuda/src/rtl.cpp b/openmp/libomptarget/plugins/cuda/src/rtl.cpp
index ece95e2e0759..49acb6cacbfe 100644
--- a/openmp/libomptarget/plugins/cuda/src/rtl.cpp
+++ b/openmp/libomptarget/plugins/cuda/src/rtl.cpp
@@ -77,7 +77,7 @@ struct KernelTy {
       : Func(_Func), ExecutionMode(_ExecutionMode) {}
 };
 
 /// Device envrionment data
 /// Manually sync with the deviceRTL side for now, move to a dedicated header file later.
 struct omptarget_device_environmentTy {
   int32_t debug_level;
@@ -451,7 +451,7 @@ __tgt_target_table *__tgt_rtl_load_binary(int32_t device_id,
       // memory is activated via the requires directive, the variable
       // can be used directly from the host in both cases.
       // TODO: when variables types other than to or link are added,
-      // the below condition should be changed to explicitely
+      // the below condition should be changed to explicitly
       // check for to and link variables types:
       //  (DeviceInfo.RequiresFlags & OMP_REQ_UNIFIED_SHARED_MEMORY &&
       //   (e->flags & OMP_DECLARE_TARGET_LINK ||
@@ -565,7 +565,7 @@ __tgt_target_table *__tgt_rtl_load_binary(int32_t device_id,
       DP("Sending global device environment data %zu bytes\n", (size_t)cusize);
     } else {
       DP("Finding global device environment '%s' - symbol missing.\n", device_env_Name);
-      DP("Continue, considering this is a device RTL which does not accept envrionment setting.\n");
+      DP("Continue, considering this is a device RTL which does not accept environment setting.\n");
     }
   }
 
@@ -77,7 +77,7 @@ struct KernelTy {
 };
 
-/// Device envrionment data
+/// Device environment data
 /// Manually sync with the deviceRTL side for now, move to a dedicated header file later.
 struct omptarget_device_environmentTy {
